# What is QUOTESX?
QUOTESX is basically a simple package to get quotes from, it is very simple and effiecient to use, only one line of code will get you a quote!

# Install Getquotesx
Simply install it from pypi.org, then type from quotesx import quotesx

# getQuote() function
The getQuote function is a simple function that will return a quote, this won't print the quote so you will have to save it to a variable later and then print it.


getQuote()
This will return a quote, it won't print it, to do that first save the quote

quote = getQuote()
This will save the quote in the 'quote variable', now you can do anything that you want with that

to print it, just add the print command.